@@ -39,7 +39,7 @@ except ImportError:  # pragma: no cover
     pygments = False
     p_ver = (0, 0)
 
-RE_PYG_CODE = re.compile(r'^<div(\s*class=".*?")?\s*>')
+RE_PYG_CODE = re.compile(r'^<(div|table)(\s*class=".*?")?\s*>')
 CODE_WRAP = '<pre{}><code{}{}{}>{}</code></pre>'
 CODE_WRAP_ON_PRE = '<pre{}{}{}><code>{}</code></pre>'
 CLASS_ATTR = ' class="{}"'
@@ -309,7 +309,10 @@ class Highlight(object):
         if attrs is None:
             attrs = {}
         class_names = classes[:] if classes else []
-        linenums_enabled = (self.linenums or (self.linenums is not False and linestart >= 0)) and not inline > 0
+        linenums_enabled = (
+            (self.linenums and linestart != 0) or
+            (self.linenums is not False and linestart > 0)
+        ) and not inline > 0
 
         # Convert with Pygments.
         if pygments and self.use_pygments:
@@ -383,8 +386,9 @@ class Highlight(object):
                 m = RE_PYG_CODE.match(code)
                 if m is not None:
                     end = m.end(0)
-                    classes = ' ' + m.group(1).lstrip() if m.group(1) else ''
-                    code = '<div{}{}{}>{}'.format(id_str, classes, attr_str, code[end:])
+                    start = m.start(0)
+                    classes = ' ' + m.group(2).lstrip() if m.group(2) else ''
+                    code = '{}<{}{}{}{}>{}'.format(code[:start], m.group(1), id_str, classes, attr_str, code[end:])
 
         elif inline:
             # Format inline code for a JavaScript Syntax Highlighter by specifying language.
