@@ -1,10 +1,7 @@
 """Test cases for SuperFences."""
 from .. import util
-import unittest
-import markdown
 import pymdownx.arithmatex as arithmatex
 import pymdownx.superfences as superfences
-from pymdownx.util import PymdownxDeprecationWarning
 import warnings
 
 
@@ -49,18 +46,373 @@ def custom_validator(language, inputs, options, attrs, md):
     return okay
 
 
-def custom_validator_legacy(language, options):
-    """Custom validator."""
+class TestHighlightTitle(util.MdCase):
+    """Test title cases."""
 
-    okay = True
-    for k in options.keys():
-        if k != 'opt':
-            okay = False
-            break
-    if okay:
-        if options['opt'] != "A":
-            okay = False
-    return okay
+    extension = ['pymdownx.highlight', 'pymdownx.superfences']
+
+    def test_title(self):
+        """Test auto title."""
+
+        self.check_markdown(
+            r'''
+            ```pycon title="My title"
+            >>> import test
+            ```
+            ''',
+            r'''
+            <div class="highlight"><span class="filename">My title</span><pre><span></span><code><span class="gp">&gt;&gt;&gt; </span><span class="kn">import</span> <span class="nn">test</span>
+            </code></pre></div>
+            ''',  # noqa: E501
+            True
+        )
+
+    def test_title_table(self):
+        """Test auto title."""
+
+        self.check_markdown(
+            r'''
+            ```pycon title="My title" linenums="1"
+            >>> import test
+            ```
+            ''',
+            r'''
+            <table class="highlighttable"><tr><th colspan="2" class="filename"><div class="highlight"><span class="filename">My title</span></div></th></tr><tr><td class="linenos"><div class="linenodiv"><pre><span></span><span class="normal">1</span></pre></div></td><td class="code"><div class="highlight"><pre><span></span><code><span class="gp">&gt;&gt;&gt; </span><span class="kn">import</span> <span class="nn">test</span>
+            </code></pre></div>
+            </td></tr></table>
+            ''',  # noqa: E501
+            True
+        )
+
+
+class TestHighlightAutoTitleOverride(util.MdCase):
+    """Test title cases."""
+
+    extension = ['pymdownx.highlight', 'pymdownx.superfences']
+    extension_configs = {
+        'pymdownx.highlight': {
+            'auto_title': True,
+            "auto_title_map": {
+                "Python Console Session": "Python"
+            }
+        }
+    }
+
+    def test_auto_tile(self):
+        """Test auto title."""
+
+        self.check_markdown(
+            r'''
+            ```{.python title="My Title"}
+            import test
+            ```
+            ''',
+            r'''
+            <div class="highlight"><span class="filename">My Title</span><pre><span></span><code><span class="kn">import</span> <span class="nn">test</span>
+            </code></pre></div>
+            ''',  # noqa: E501
+            True
+        )
+
+    def test_auto_tile_map(self):
+        """Test auto title."""
+
+        self.check_markdown(
+            r'''
+            ```{.pycon title="My Title"}
+            >>> import test
+            ```
+            ''',
+            r'''
+            <div class="highlight"><span class="filename">My Title</span><pre><span></span><code><span class="gp">&gt;&gt;&gt; </span><span class="kn">import</span> <span class="nn">test</span>
+            </code></pre></div>
+            ''',  # noqa: E501
+            True
+        )
+
+
+class TestHighlightLineWrapsInline(util.MdCase):
+    """Test highlight line wraps."""
+
+    extension = ['pymdownx.highlight', 'pymdownx.superfences']
+    extension_configs = {
+        'pymdownx.highlight': {
+            'line_spans': '__my_span',
+            'linenums_style': 'inline'
+        }
+    }
+
+    def test_linespans(self):
+        """Test wrapping a line in line spans."""
+
+        self.check_markdown(
+            r'''
+            ```python linenums="2"
+            import test
+            ```
+            ''',
+            r'''
+            <div class="highlight"><pre><span></span><code><span id="__my_span-0-2"><span class="linenos">2</span><span class="kn">import</span> <span class="nn">test</span>
+            </span></code></pre></div>
+            ''',  # noqa: E501
+            True
+        )
+
+
+class TestHighlightLineWrapsPymdownxInline(util.MdCase):
+    """Test highlight line wraps."""
+
+    extension = ['pymdownx.highlight', 'pymdownx.superfences']
+    extension_configs = {
+        'pymdownx.highlight': {
+            'line_spans': '__my_span',
+            'linenums_style': 'pymdownx-inline'
+        }
+    }
+
+    def test_linespans(self):
+        """Test wrapping a line in line spans."""
+
+        self.check_markdown(
+            r'''
+            ```python linenums="2"
+            import test
+            ```
+            ''',
+            r'''
+            <div class="highlight"><pre><span></span><code><span id="__my_span-0-2"><span class="linenos" data-linenos="2 "></span><span class="kn">import</span> <span class="nn">test</span>
+            </span></code></pre></div>
+            ''',  # noqa: E501
+            True
+        )
+
+
+class TestHighlightLineWrapsPymdownsTable(util.MdCase):
+    """Test highlight line wraps."""
+
+    extension = ['pymdownx.highlight', 'pymdownx.superfences']
+    extension_configs = {
+        'pymdownx.highlight': {
+            'line_spans': '__my_span',
+            'linenums_style': 'table'
+        }
+    }
+
+    def test_linespans(self):
+        """Test wrapping a line in line spans."""
+
+        self.check_markdown(
+            r'''
+            ```python linenums="2"
+            import test
+            ```
+            ''',
+            r'''
+            <table class="highlighttable"><tr><td class="linenos"><div class="linenodiv"><pre><span></span><span class="normal">2</span></pre></div></td><td class="code"><div class="highlight"><pre><span></span><code><span id="__my_span-0-2"><span class="kn">import</span> <span class="nn">test</span>
+            </span></code></pre></div>
+            </td></tr></table>
+            ''',  # noqa: E501
+            True
+        )
+
+
+class TestHighlightLineAnchorsInline(util.MdCase):
+    """Test highlight line wraps."""
+
+    extension = ['pymdownx.highlight', 'pymdownx.superfences']
+    extension_configs = {
+        'pymdownx.highlight': {
+            'line_anchors': '__my_span',
+            'linenums_style': 'inline'
+        }
+    }
+
+    def test_linespans(self):
+        """Test wrapping a line in line spans."""
+
+        self.check_markdown(
+            r'''
+            ```python linenums="2"
+            import test
+            ```
+            ''',
+            r'''
+            <div class="highlight"><pre><span></span><code><a id="__my_span-0-2" name="__my_span-0-2"></a><span class="linenos">2</span><span class="kn">import</span> <span class="nn">test</span>
+            </code></pre></div>
+            ''',  # noqa: E501
+            True
+        )
+
+
+class TestHighlightLineAnchorsPymdownxInline(util.MdCase):
+    """Test highlight line wraps."""
+
+    extension = ['pymdownx.highlight', 'pymdownx.superfences']
+    extension_configs = {
+        'pymdownx.highlight': {
+            'line_anchors': '__my_span',
+            'linenums_style': 'pymdownx-inline'
+        }
+    }
+
+    def test_linespans(self):
+        """Test wrapping a line in line spans."""
+
+        self.check_markdown(
+            r'''
+            ```python linenums="2"
+            import test
+            ```
+            ''',
+            r'''
+            <div class="highlight"><pre><span></span><code><a id="__my_span-0-2" name="__my_span-0-2"></a><span class="linenos" data-linenos="2 "></span><span class="kn">import</span> <span class="nn">test</span>
+            </code></pre></div>
+            ''',  # noqa: E501
+            True
+        )
+
+
+class TestHighlightLineAnchorsPymdownsTable(util.MdCase):
+    """Test highlight line wraps."""
+
+    extension = ['pymdownx.highlight', 'pymdownx.superfences']
+    extension_configs = {
+        'pymdownx.highlight': {
+            'line_anchors': '__my_span',
+            'linenums_style': 'table'
+        }
+    }
+
+    def test_linespans(self):
+        """Test wrapping a line in line spans."""
+
+        self.check_markdown(
+            r'''
+            ```python linenums="2"
+            import test
+            ```
+            ''',
+            r'''
+            <table class="highlighttable"><tr><td class="linenos"><div class="linenodiv"><pre><span></span><span class="normal">2</span></pre></div></td><td class="code"><div class="highlight"><pre><span></span><code><a id="__my_span-0-2" name="__my_span-0-2"></a><span class="kn">import</span> <span class="nn">test</span>
+            </code></pre></div>
+            </td></tr></table>
+            ''',  # noqa: E501
+            True
+        )
+
+
+class TestHighlightAnchorLinenumInline(util.MdCase):
+    """Test highlight line wraps."""
+
+    extension = ['pymdownx.highlight', 'pymdownx.superfences']
+    extension_configs = {
+        'pymdownx.highlight': {
+            'anchor_linenums': True,
+            'linenums_style': 'inline'
+        }
+    }
+
+    def test_linespans(self):
+        """Test wrapping a line in line spans."""
+
+        self.check_markdown(
+            r'''
+            ```python linenums="2"
+            import test
+            ```
+            ''',
+            r'''
+            <div class="highlight"><pre><span></span><code><a id="__codelineno-0-2" name="__codelineno-0-2"></a><a href="#__codelineno-0-2"><span class="linenos">2</span></a><span class="kn">import</span> <span class="nn">test</span>
+            </code></pre></div>
+            ''',  # noqa: E501
+            True
+        )
+
+
+class TestHighlightAnchorLinenumsPymdownxInline(util.MdCase):
+    """Test highlight line wraps."""
+
+    extension = ['pymdownx.highlight', 'pymdownx.superfences']
+    extension_configs = {
+        'pymdownx.highlight': {
+            'anchor_linenums': True,
+            'linenums_style': 'pymdownx-inline'
+        }
+    }
+
+    def test_linespans(self):
+        """Test wrapping a line in line spans."""
+
+        self.check_markdown(
+            r'''
+            ```python linenums="2"
+            import test
+            ```
+            ''',
+            r'''
+            <div class="highlight"><pre><span></span><code><a id="__codelineno-0-2" name="__codelineno-0-2"></a><a href="#__codelineno-0-2"><span class="linenos" data-linenos="2 "></span></a><span class="kn">import</span> <span class="nn">test</span>
+            </code></pre></div>
+            ''',  # noqa: E501
+            True
+        )
+
+
+class TestHighlightAnchorLinenumsPymdownsTable(util.MdCase):
+    """Test highlight line wraps."""
+
+    extension = ['pymdownx.highlight', 'pymdownx.superfences']
+    extension_configs = {
+        'pymdownx.highlight': {
+            'anchor_linenums': True,
+            'linenums_style': 'table'
+        }
+    }
+
+    def test_linespans(self):
+        """Test wrapping a line in line spans."""
+
+        self.check_markdown(
+            r'''
+            ```python linenums="2"
+            import test
+            ```
+            ''',
+            r'''
+            <table class="highlighttable"><tr><td class="linenos"><div class="linenodiv"><pre><span></span><span class="normal"><a href="#__codelineno-0-2">2</a></span></pre></div></td><td class="code"><div class="highlight"><pre><span></span><code><a id="__codelineno-0-2" name="__codelineno-0-2"></a><span class="kn">import</span> <span class="nn">test</span>
+            </code></pre></div>
+            </td></tr></table>
+            ''',  # noqa: E501
+            True
+        )
+
+
+class TestHighlightAnchorLinenumNameInline(util.MdCase):
+    """Test highlight line wraps."""
+
+    extension = ['pymdownx.highlight', 'pymdownx.superfences']
+    extension_configs = {
+        'pymdownx.highlight': {
+            'anchor_linenums': True,
+            'line_anchors': '__my_span',
+            'linenums_style': 'inline'
+        }
+    }
+
+    def test_linespans(self):
+        """Test wrapping a line in line spans."""
+
+        self.check_markdown(
+            r'''
+            ```python linenums="2"
+            import test
+            ```
+            ''',
+            r'''
+            <div class="highlight"><pre><span></span><code><a id="__my_span-0-2" name="__my_span-0-2"></a><a href="#__my_span-0-2"><span class="linenos">2</span></a><span class="kn">import</span> <span class="nn">test</span>
+            </code></pre></div>
+            ''',  # noqa: E501
+            True
+        )
 
 
 class TestHighlightLines(util.MdCase):
@@ -198,9 +550,9 @@ class TestSuperFencesClassesIds(util.MdCase):
             ```
             ''',
             r'''
-            <div class="highlight"><pre><span></span><code><span class="kn">import</span> <span class="nn">test</span>
+            <div id="id" class="highlight"><pre><span></span><code><span class="kn">import</span> <span class="nn">test</span>
             </code></pre></div>
-            ''',
+            ''',  # noqa: E501
             True
         )
 
@@ -214,9 +566,9 @@ class TestSuperFencesClassesIds(util.MdCase):
             ```
             ''',
             r'''
-            <div class="highlight"><pre><span></span><code><span class="kn">import</span> <span class="nn">test</span>
+            <div id="id" class="highlight"><pre><span></span><code><span class="kn">import</span> <span class="nn">test</span>
             </code></pre></div>
-            ''',
+            ''',  # noqa: E501
             True
         )
 
@@ -253,14 +605,14 @@ class TestSuperFencesClassesIdsAttrList(util.MdCase):
             ```
             ''',
             r'''
-            <div class="highlight"><pre><span></span><code><span class="kn">import</span> <span class="nn">test</span>
+            <div id="id" class="highlight"><pre><span></span><code><span class="kn">import</span> <span class="nn">test</span>
             </code></pre></div>
-            ''',
+            ''',  # noqa: E501
             True
         )
 
-    def test_attr(self):
-        """Test extra attributes."""
+    def test_bad_attr(self):
+        """Test bad attribute."""
 
         self.check_markdown(
             r'''
@@ -269,9 +621,42 @@ class TestSuperFencesClassesIdsAttrList(util.MdCase):
             ```
             ''',
             r'''
-            <div class="highlight"><pre><span></span><code><span class="kn">import</span> <span class="nn">test</span>
+            <div id="id" class="highlight"><pre><span></span><code><span class="kn">import</span> <span class="nn">test</span>
             </code></pre></div>
+            ''',  # noqa: E501
+            True
+        )
+
+    def test_data_attr(self):
+        """Test data attributes."""
+
+        self.check_markdown(
+            r'''
+            ```{.python #id data-attr="test"}
+            import test
+            ```
             ''',
+            r'''
+            <div id="id" class="highlight" data-attr="test"><pre><span></span><code><span class="kn">import</span> <span class="nn">test</span>
+            </code></pre></div>
+            ''',  # noqa: E501
+            True
+        )
+
+    def test_data_attr_linenums(self):
+        """Test data attributes with line numbers enabled."""
+
+        self.check_markdown(
+            r'''
+            ```{.python #id data-attr="test" linenums="1"}
+            import test
+            ```
+            ''',
+            r'''
+            <table id="id" class="highlighttable" data-attr="test"><tr><td class="linenos"><div class="linenodiv"><pre><span></span><span class="normal">1</span></pre></div></td><td class="code"><div class="highlight"><pre><span></span><code><span class="kn">import</span> <span class="nn">test</span>
+            </code></pre></div>
+            </td></tr></table>
+            ''',  # noqa: E501
             True
         )
 
@@ -389,49 +774,6 @@ class TestSuperFencesClassesIdsAttrListNoPygmentsOnPre(util.MdCase):
         )
 
 
-class TestWaringings(unittest.TestCase):
-    """Test warnings."""
-
-    def test_highlight_code(self):
-        """Test highlight code warning."""
-
-        with warnings.catch_warnings(record=True) as w:
-            warnings.simplefilter("always")
-
-            markdown.Markdown(
-                extensions=['pymdownx.superfences'],
-                extension_configs={'pymdownx.superfences': {'highlight_code': False}}
-            ).convert('```\ntest\n```\n')
-
-            self.assertTrue(len(w) == 1)
-            self.assertTrue(issubclass(w[-1].category, PymdownxDeprecationWarning))
-
-    def test_legacy_validator_code(self):
-        """Test legacy validator."""
-
-        with warnings.catch_warnings(record=True) as w:
-            warnings.simplefilter("always")
-
-            markdown.Markdown(
-                extensions=['pymdownx.superfences'],
-                extension_configs={
-                    'pymdownx.superfences': {
-                        'custom_fences': [
-                            {
-                                'name': 'test',
-                                'class': 'test',
-                                'format': custom_format,
-                                'validator': custom_validator_legacy
-                            }
-                        ]
-                    }
-                }
-            ).convert('```\ntest\n```\n')
-
-            self.assertTrue(len(w) == 1)
-            self.assertTrue(issubclass(w[-1].category, PymdownxDeprecationWarning))
-
-
 class TestSuperFencesBad(util.MdCase):
     """Test bad options."""
 
@@ -477,71 +819,6 @@ class TestSuperFencesBad(util.MdCase):
         )
 
 
-class TestSuperFencesCustomLegacy(util.MdCase):
-    """Test custom legacy validator."""
-
-    extension = ['pymdownx.superfences']
-    extension_configs = {
-        'pymdownx.superfences': {
-            'custom_fences': [
-                {
-                    'name': 'test',
-                    'class': 'test',
-                    'format': custom_format,
-                    'validator': custom_validator_legacy
-                }
-            ]
-        }
-    }
-
-    def test_bad_options(self):
-        """Test bad options."""
-
-        self.check_markdown(
-            r'''
-            ```test bad="bad"
-            test
-            ```
-            ''',
-            r'''
-            <p><code>test bad="bad"
-            test</code></p>
-            ''',
-            True
-        )
-
-    def test_bad_option_value(self):
-        """Test bad options."""
-
-        self.check_markdown(
-            r'''
-            ```test opt="B"
-            test
-            ```
-            ''',
-            r'''
-            <p><code>test opt="B"
-            test</code></p>
-            ''',
-            True
-        )
-
-    def test_custom_options(self):
-        """Test options."""
-
-        self.check_markdown(
-            r'''
-            ```test opt="A"
-            test
-            ```
-            ''',
-            r'''
-            <div lang="test" class_name="class-test", option="A">test</div>
-            ''',
-            True
-        )
-
-
 class TestSuperFencesCustom(util.MdCase):
     """Test custom validator and format."""
 
@@ -666,7 +943,7 @@ class TestSuperFencesCustomArithmatex(util.MdCase):
                 {
                     'name': 'math',
                     'class': 'arithmatex',
-                    'format': arithmatex.fence_mathjax_format
+                    'format': arithmatex.arithmatex_fenced_format(mode="mathjax")
                 }
             ]
         }
@@ -682,14 +959,56 @@ class TestSuperFencesCustomArithmatex(util.MdCase):
             ```
             ''',
             r'''
+            <div class="arithmatex">
             <script type="math/tex; mode=display">
             E(\mathbf{v}, \mathbf{h}) = -\sum_{i,j}w_{ij}v_i h_j - \sum_i b_i v_i - \sum_j c_j h_j
             </script>
+            </div>
             ''',
             True
         )
 
 
+class TestSuperFencesCustomLegacyArithmatex(util.MdCase):
+    """Test custom Arithmatex format."""
+
+    extension = ['pymdownx.superfences']
+    extension_configs = {
+        'pymdownx.superfences': {
+            'custom_fences': [
+                {
+                    'name': 'math',
+                    'class': 'arithmatex',
+                    'format': arithmatex.fence_mathjax_format
+                }
+            ]
+        }
+    }
+
+    def test_legacy_arithmatex(self):
+        """Test Arithmatex formatter without preview."""
+
+        with warnings.catch_warnings(record=True) as w:
+            self.check_markdown(
+                r'''
+                ```math
+                E(\mathbf{v}, \mathbf{h}) = -\sum_{i,j}w_{ij}v_i h_j - \sum_i b_i v_i - \sum_j c_j h_j
+                ```
+                ''',
+                r'''
+                <div class="arithmatex">
+                <script type="math/tex; mode=display">
+                E(\mathbf{v}, \mathbf{h}) = -\sum_{i,j}w_{ij}v_i h_j - \sum_i b_i v_i - \sum_j c_j h_j
+                </script>
+                </div>
+                ''',
+                True
+            )
+
+            self.assertTrue(len(w) == 1)
+            self.assertTrue(issubclass(w[-1].category, DeprecationWarning))
+
+
 class TestSuperFencesCustomArithmatexPreview(util.MdCase):
     """Test custom Arithmatex preview format."""
 
@@ -700,7 +1019,7 @@ class TestSuperFencesCustomArithmatexPreview(util.MdCase):
                 {
                     'name': 'math',
                     'class': 'arithmatex',
-                    'format': arithmatex.fence_mathjax_preview_format
+                    'format': arithmatex.arithmatex_fenced_format(mode='mathjax', preview=True)
                 }
             ]
         }
@@ -716,7 +1035,7 @@ class TestSuperFencesCustomArithmatexPreview(util.MdCase):
             ```
             ''',
             r'''
-            <div>
+            <div class="arithmatex">
             <div class="MathJax_Preview">
             E(\mathbf{v}, \mathbf{h}) = -\sum_{i,j}w_{ij}v_i h_j - \sum_i b_i v_i - \sum_j c_j h_j
             </div>
@@ -729,6 +1048,49 @@ class TestSuperFencesCustomArithmatexPreview(util.MdCase):
         )
 
 
+class TestSuperFencesCustomLegacyArithmatexPreview(util.MdCase):
+    """Test custom Arithmatex preview format."""
+
+    extension = ['pymdownx.superfences']
+    extension_configs = {
+        'pymdownx.superfences': {
+            'custom_fences': [
+                {
+                    'name': 'math',
+                    'class': 'arithmatex',
+                    'format': arithmatex.fence_mathjax_preview_format
+                }
+            ]
+        }
+    }
+
+    def test_legacy_arithmatex_preview(self):
+        """Test Arithmatex formatter with preview."""
+
+        with warnings.catch_warnings(record=True) as w:
+            self.check_markdown(
+                r'''
+                ```math
+                E(\mathbf{v}, \mathbf{h}) = -\sum_{i,j}w_{ij}v_i h_j - \sum_i b_i v_i - \sum_j c_j h_j
+                ```
+                ''',
+                r'''
+                <div class="arithmatex">
+                <div class="MathJax_Preview">
+                E(\mathbf{v}, \mathbf{h}) = -\sum_{i,j}w_{ij}v_i h_j - \sum_i b_i v_i - \sum_j c_j h_j
+                </div>
+                <script type="math/tex; mode=display">
+                E(\mathbf{v}, \mathbf{h}) = -\sum_{i,j}w_{ij}v_i h_j - \sum_i b_i v_i - \sum_j c_j h_j
+                </script>
+                </div>
+                ''',
+                True
+            )
+
+            self.assertTrue(len(w) == 1)
+            self.assertTrue(issubclass(w[-1].category, DeprecationWarning))
+
+
 class TestSuperFencesCustomArithmatexGeneric(util.MdCase):
     """Test custom Arithmatex generic format."""
 
@@ -739,7 +1101,7 @@ class TestSuperFencesCustomArithmatexGeneric(util.MdCase):
                 {
                     'name': 'math',
                     'class': 'arithmatex',
-                    'format': arithmatex.fence_generic_format
+                    'format': arithmatex.arithmatex_fenced_format(mode="generic")
                 }
             ]
         }
@@ -763,6 +1125,44 @@ class TestSuperFencesCustomArithmatexGeneric(util.MdCase):
         )
 
 
+class TestSuperFencesCustomLegacyArithmatexGeneric(util.MdCase):
+    """Test custom Arithmatex generic format."""
+
+    extension = ['pymdownx.superfences']
+    extension_configs = {
+        'pymdownx.superfences': {
+            'custom_fences': [
+                {
+                    'name': 'math',
+                    'class': 'arithmatex',
+                    'format': arithmatex.fence_generic_format
+                }
+            ]
+        }
+    }
+
+    def test_legacy_arithmatex_generic(self):
+        """Test Arithmatex generic formatter."""
+
+        with warnings.catch_warnings(record=True) as w:
+            self.check_markdown(
+                r'''
+                ```math
+                E(\mathbf{v}, \mathbf{h}) = -\sum_{i,j}w_{ij}v_i h_j - \sum_i b_i v_i - \sum_j c_j h_j
+                ```
+                ''',
+                r'''
+                <div class="arithmatex">\[
+                E(\mathbf{v}, \mathbf{h}) = -\sum_{i,j}w_{ij}v_i h_j - \sum_i b_i v_i - \sum_j c_j h_j
+                \]</div>
+                ''',
+                True
+            )
+
+            self.assertTrue(len(w) == 1)
+            self.assertTrue(issubclass(w[-1].category, DeprecationWarning))
+
+
 class TestSuperFencesCustomDefault(util.MdCase):
     """Test overriding the default format."""
 
@@ -778,7 +1178,7 @@ class TestSuperFencesCustomDefault(util.MdCase):
                 {
                     'name': 'math',
                     'class': 'arithmatex',
-                    'format': arithmatex.fence_generic_format
+                    'format': arithmatex.arithmatex_fenced_format(mode="generic")
                 }
             ]
         }
